#! /bin/sh
#   +-------------------------------------------------------------------+
#   | Licensed Materials - Property of IBM                              |
#   | 5697-B83                                                          |
#   | (C) Copyright Tivoli Systems, an IBM Company 1982, 1997           |
#   | All rights reserved.                                              |
#   | (C) Copyright IBM Corp. 1982, 1997.  All rights reserved.         |
#   |                                                                   |
#   | US Government Users Restricted Rights - Use, duplication or       |
#   | disclosure restricted by GSA ADP Schedule Contract with IBM Corp. |
#   +-------------------------------------------------------------------+
###############################################################################
#                                                                             #
# Name       : createtasklibrary.sh                                           #
#                                                                             #
# Author     : Paul J. Liskay 02/25/97                                        #
#            : K Norsworthy 04/15/97                                          #
#                                                                             #
# Description: creates a task library for the policy region                   #
#              gurn.raleigh.ibm.com-region and adds a bunch                   #
#              of tasks to that library                                       #
#                                                                             #
# Changes    : 04/07/97 PJL added tec_clearTriggerTable                       #
#            : 04/15/97 Removed dialog tasks and invoke tec_inst.sh           #
#            : 06/06/97 PJL added getLastRelThreshold                         #
#            : 06/09/97 KEN added getLastThreshold                            #
#            : 06/09/97 PJL added Query Interval                              #
#            : 07/25/97 PJL added tec_setReportModeAll/TEC                    #
#                                                                             #
###############################################################################

#Create Operating System Flag
if [ -n "$windir" ] ; then
   WINOS=`echo $windir | awk /:/'{ print substr($1,4) }'`
   WINDRIVE=`echo $windir | awk /:/'{ print substr($1,1,2) }'`
fi

if [ -n "$WINOS" ]
then source $WINDRIVE/$WINOS/system32/drivers/etc/Tivoli/setup_env.sh
else . /etc/Tivoli/setup_env.sh
fi

#create the task library
IRO=`wlookup InterRegion`
IROname=`idlattr -t -g $IRO name string`
IROname=`eval echo $IROname`
echo "Creating the task library for $IROname ..."
wcrttlib "APM_Tivoli_Tivoli/Enterprise Console_3.1" $IROname

#delete all of the previous tasks before reinstalling
echo "Deleting all instances of previously installed tasks..."
echo " (if this is your first install, ignore the following messages)."
wdeltask "Discover_Connections"            "APM_Tivoli_Tivoli/Enterprise Console_3.1"
wdeltask "Query_Contact"                   "APM_Tivoli_Tivoli/Enterprise Console_3.1"
wdeltask "Query_Interval"                  "APM_Tivoli_Tivoli/Enterprise Console_3.1"
wdeltask "Query_Rel_Threshold"             "APM_Tivoli_Tivoli/Enterprise Console_3.1"
wdeltask "Query Reporting Mode"            "APM_Tivoli_Tivoli/Enterprise Console_3.1"
wdeltask "Query TEC State"                 "APM_Tivoli_Tivoli/Enterprise Console_3.1"
wdeltask "Query_TEC_Values"                "APM_Tivoli_Tivoli/Enterprise Console_3.1"
wdeltask "Query_Threshold"                 "APM_Tivoli_Tivoli/Enterprise Console_3.1"
wdeltask "Report All Connections"          "APM_Tivoli_Tivoli/Enterprise Console_3.1"
wdeltask "Report Only TEC-TEC Connections" "APM_Tivoli_Tivoli/Enterprise Console_3.1"
wdeltask "Set_Polling_Interval"            "APM_Tivoli_Tivoli/Enterprise Console_3.1"
wdeltask "Set_TEC_Pulse"                   "APM_Tivoli_Tivoli/Enterprise Console_3.1"
wdeltask "Set_TEC_Rel_Threshold"           "APM_Tivoli_Tivoli/Enterprise Console_3.1"
wdeltask "Set_TEC_Threshold"               "APM_Tivoli_Tivoli/Enterprise Console_3.1"
wdeltask "Start TEC Event Server"          "APM_Tivoli_Tivoli/Enterprise Console_3.1"
wdeltask "Stop TEC Event Server"           "APM_Tivoli_Tivoli/Enterprise Console_3.1"
wdeltask "TEC_Clear_Closed_Events"         "APM_Tivoli_Tivoli/Enterprise Console_3.1"
wdeltask "TEC Clear Reception Log"         "APM_Tivoli_Tivoli/Enterprise Console_3.1"
wdeltask "TEC Clear Trigger Table"         "APM_Tivoli_Tivoli/Enterprise Console_3.1"
wdeltask "TEC Create Trigger"              "APM_Tivoli_Tivoli/Enterprise Console_3.1"
wdeltask "TEC DataBase Status"             "APM_Tivoli_Tivoli/Enterprise Console_3.1"
wdeltask "TEC Device Space Free (MB)"      "APM_Tivoli_Tivoli/Enterprise Console_3.1"
wdeltask "TEC Device Space Free (pct)"     "APM_Tivoli_Tivoli/Enterprise Console_3.1"
wdeltask "TEC Device Space Used (MB)"      "APM_Tivoli_Tivoli/Enterprise Console_3.1"
wdeltask "TEC Device Space Used (pct)"     "APM_Tivoli_Tivoli/Enterprise Console_3.1"
wdeltask "TEC Server Status"               "APM_Tivoli_Tivoli/Enterprise Console_3.1"

# Create the Task Dialogs
# Check for operating system
echo "Creating the Task Dialog Library... please be patient."

if [ -n "$windir" ] ;
   then wtll -r -p "$IROname" -P $BINDIR/tools/cat $BINDIR/TME/TEC/interapp/tec_inst.tll
   else wtll -r -p "$IROname" -P /usr/bin/cat $BINDIR/TME/TEC/interapp/tec_inst.tll
fi

# Create the tasks that use TLL
# Set the user priviledge
echo "Creating the Discover_Connections task..."
wsettask -t "Discover_Connections" -l "APM_Tivoli_Tivoli/Enterprise Console_3.1" -u "*"

echo "Creating the Query_Contact task..."
wsettask -t "Query_Contact" -l "APM_Tivoli_Tivoli/Enterprise Console_3.1" -u "*"

echo "Creating the Query_Interval task..."
wsettask -t "Query_Interval" -l "APM_Tivoli_Tivoli/Enterprise Console_3.1" -u "*"

echo "Creating the Query_TEC_Values task..."
wsettask -t "Query_TEC_Values" -l "APM_Tivoli_Tivoli/Enterprise Console_3.1" -u "*"

echo "Creating the Query_Threshold task..."
wsettask -t "Query_Threshold" -l "APM_Tivoli_Tivoli/Enterprise Console_3.1" -u "*"

echo "Creating the Set_Polling_Interval task..."
wsettask -t "Set_Polling_Interval" -l "APM_Tivoli_Tivoli/Enterprise Console_3.1" -u "*"

echo "Creating the Set_TEC_Pulse..."
wsettask -t "Set_TEC_Pulse" -l "APM_Tivoli_Tivoli/Enterprise Console_3.1" -u "*"

echo "Creating the Set_TEC_Rel_Threshold task..."
wsettask -t "Set_TEC_Rel_Threshold" -l "APM_Tivoli_Tivoli/Enterprise Console_3.1" -u "*"

echo "Creating the Set_TEC_Threshold task..."
wsettask -t "Set_TEC_Threshold" -l "APM_Tivoli_Tivoli/Enterprise Console_3.1" -u "*"

echo "Creating the TEC_Clear_Closed_Events task..."
wsettask -t "TEC_Clear_Closed_Events" -l "APM_Tivoli_Tivoli/Enterprise Console_3.1" -u "*"

# first, determine the ManagedNodeName for this machine
BASE_OID=`objcall 0.0.0 self`
HOST_OID=`objcall $BASE_OID getattr HostLocation`
HOST_NAME=`idlcall $HOST_OID _get_label`
HOST_NAME=`echo $HOST_NAME|cut -d'"' -f2`

#add the operational tasks defined in tec.cdf to this library

echo "Creating the Query_Rel_Threshold task..."
wcrttask -t "Query_Rel_Threshold" -l "APM_Tivoli_Tivoli/Enterprise Console_3.1#$IROname" -r admin:senior:super \
         -i default  $HOST_NAME $BINDIR/TME/TEC/interapp/getLastRelThreshold.sh \
         -c "gets the last relationship thresholds"

echo "Creating the Query Reporting Mode task..."
wcrttask -t "Query Reporting Mode" -l "APM_Tivoli_Tivoli/Enterprise Console_3.1#$IROname" -r admin:senior:super \
         -i default  $HOST_NAME $BINDIR/TME/TEC/interapp/tec_queryReportMode \
         -c "querys the Reporting Mode (all/tec)"

echo "Creating the Query TEC State task..."
wcrttask -t "Query TEC State" -l "APM_Tivoli_Tivoli/Enterprise Console_3.1#$IROname" -r admin:senior:super \
         -i default  $HOST_NAME $BINDIR/TME/TEC/interapp/querystate \
         -c "querys TEC state"

echo "Creating the Report All Connections task..."
wcrttask -t "Report All Connections" -l "APM_Tivoli_Tivoli/Enterprise Console_3.1#$IROname" -r admin:senior:super \
         -i default $HOST_NAME $BINDIR/TME/TEC/interapp/tec_setReportModeAll \
         -c "sets Reporting Mode to All"

echo "Creating the Report Only TEC-TEC Connections task..."
wcrttask -t "Report Only TEC-TEC Connections" -l "APM_Tivoli_Tivoli/Enterprise Console_3.1#$IROname" -r admin:senior:super \
         -i default $HOST_NAME $BINDIR/TME/TEC/interapp/tec_setReportModeTEC \
         -c "sets Reporting Mode to TEC-TEC only"

echo "Creating the Start TEC Event Server task..."
wcrttask -t "Start TEC Event Server" -l "APM_Tivoli_Tivoli/Enterprise Console_3.1#$IROname" -r admin:senior:super \
         -i default $HOST_NAME $BINDIR/TME/TEC/interapp/startcomponent \
         -c "starts the TEC Event Server"

echo "Creating the Stop TEC Event Server task..."
wcrttask -t "Stop TEC Event Server" -l "APM_Tivoli_Tivoli/Enterprise Console_3.1#$IROname" -r admin:senior:super \
         -i default $HOST_NAME $BINDIR/TME/TEC/interapp/stopcomponent \
         -c "stops the TEC Event Server"

echo "Creating the TEC Clear Reception Log task..."
wcrttask -t "TEC Clear Reception Log" -l "APM_Tivoli_Tivoli/Enterprise Console_3.1#$IROname" -r admin:senior:super \
         -i default $HOST_NAME $BINDIR/TME/TEC/interapp/tec_clearReceptionLog \
         -c "clears the TEC Reception Log"

echo "Creating the TEC Clear Trigger Table task..."
wcrttask -t "TEC Clear Trigger Table" -l "APM_Tivoli_Tivoli/Enterprise Console_3.1#$IROname" -r admin:senior:super \
         -i default $HOST_NAME $BINDIR/TME/TEC/interapp/tec_clearTriggerTable \
         -c "clears rows over 1 hour old from tec_t_gem_threshold"

echo "Creating the TEC Create Trigger task..."
wcrttask -t "TEC Create Trigger" -l "APM_Tivoli_Tivoli/Enterprise Console_3.1#$IROname" -r admin:senior:super \
         -i default $HOST_NAME $BINDIR/TME/TEC/interapp/tec_createTrigger \
         -c "creates the trigger for tec_t_gem_threshold"

echo "Creating the TEC DataBase Status task..."
wcrttask -t "TEC DataBase Status" -l "APM_Tivoli_Tivoli/Enterprise Console_3.1#$IROname" -r admin:senior:super \
         -i default $HOST_NAME $BINDIR/TME/TEC/interapp/tec_DataBaseStatus \
         -c "reports the status of the TEC DataBase"

echo "Creating the TEC Device Space Free (MB) task..."
wcrttask -t "TEC Device Space Free (MB)" -l "APM_Tivoli_Tivoli/Enterprise Console_3.1#$IROname" -r admin:senior:super \
         -i default $HOST_NAME $BINDIR/TME/TEC/interapp/tec_DeviceSpaceFree \
         -c "reports the number of MegaBytes free in the TEC Device Space"

echo "Creating the TEC Device Space Free (pct) task..."
wcrttask -t "TEC Device Space Free (pct)" -l "APM_Tivoli_Tivoli/Enterprise Console_3.1#$IROname" -r admin:senior:super \
         -i default $HOST_NAME $BINDIR/TME/TEC/interapp/tec_DeviceSpaceFreepct \
         -c "reports the percentage of disk space free in the TEC Device Space"

echo "Creating the TEC Device Space Used (MB) task..."
wcrttask -t "TEC Device Space Used (MB)" -l "APM_Tivoli_Tivoli/Enterprise Console_3.1#$IROname" -r admin:senior:super \
         -i default $HOST_NAME $BINDIR/TME/TEC/interapp/tec_DeviceSpaceUsed \
         -c "reports the number of MegaBytes used in the TEC Device Space"

echo "Creating the TEC Device Space Used (pct) task..."
wcrttask -t "TEC Device Space Used (pct)" -l "APM_Tivoli_Tivoli/Enterprise Console_3.1#$IROname" -r admin:senior:super \
         -i default $HOST_NAME $BINDIR/TME/TEC/interapp/tec_DeviceSpaceUsedpct \
         -c "reports the percentage of disk space used in the TEC Device Space"

echo "Creating the TEC Server Status task..."
wcrttask -t "TEC Server Status" -l "APM_Tivoli_Tivoli/Enterprise Console_3.1#$IROname" -r admin:senior:super \
         -i default $HOST_NAME $BINDIR/TME/TEC/interapp/tec_ServerStatus \
         -c "returns the status of the TEC Server viz Up/Down"

echo "Done."
exit 0

