#! /bin/sh
#-------------------------------------------------------------------------------
#   +-------------------------------------------------------------------+
#   | Licensed Materials - Property of IBM                              |
#   | 5697-B83                                                          |
#   | (C) Copyright Tivoli Systems, an IBM Company 1982, 1997           |
#   | All rights reserved.                                              |
#   | (C) Copyright IBM Corp. 1982, 1997.  All rights reserved.         |
#   |                                                                   |
#   | US Government Users Restricted Rights - Use, duplication or       |
#   | disclosure restricted by GSA ADP Schedule Contract with IBM Corp. |
#   +-------------------------------------------------------------------+
#
# Program:      getLastRelThreshold.sh
#
# Description:  Queries the number of events received in the past
#               hour for each connection to TEC.  If a number
#               exceeds a threshold as defined in thresh.rate,
#               then an APM_THRESHOLD event is generated
#
# Author:       Paul J. Liskay 06/06/97
#
# Parameters:   None
#
# Returns:      0 - normal completion
#               1 - abnormal termination
#
# Assumptions:
#
# Limitations:
#
# Changes:      07/22/97 changed "origin <> ''" to "origin IS NOT NULL"
#               07/29/97 added check for REPORTMODE and exit if mode is tec
#               08/20/97 KHM 35674 Removed <> in sql query for ORIGIN value
#               09/29/97 D36321 changed monitor=EventsReceivedRate to
#                                        monitor=Events Received Rate ()
#
#-------------------------------------------------------------------------------

#Create Operating System Flag
if [ -n "$windir" ] ; then
   WINOS=`echo $windir | awk /:/'{ print substr($1,4) }'`
   WINDRIVE=`echo $windir | awk /:/'{ print substr($1,1,2) }'`
fi

if [ -n "$WINOS" ]
then source $WINDRIVE/$WINOS/system32/drivers/etc/Tivoli/setup_env.sh
else . /etc/Tivoli/setup_env.sh
fi

#kludge to support Solaris, nslookup is in one of these paths
PATH=$PATH:/usr/sbin:/usr/etc
export PATH
UNAME=`uname`

#Get Reporting Mode Flag
REPORTMODE=`grep REPORTING_MODE $BINDIR/TME/TEC/interapp/discoverConnections.dat | cut -d'=' -f2`

#If we are reporting only TEC->TEC connections, then exit since we can't determine
#the number of events forwarded to another TEC.
if [ $REPORTMODE = "tec" ]
   then exit 1
fi

echo Getting last threshold information...

DATFILE=/tmp/lastthresh.in
TNR=`wlookup NameRegistry`
ES=`idlcall $TNR local_lookup '"EventServer" "EventServer"'`
EVENTSERVEROID=`idlarg 1 $ES`
THISHOSTNAME=`hostname`

#req'd for AIX 4.1 (ps truncates to COLUMNS)
COLUMNS=200
export COLUMNS

rm /tmp/lastthresh.in    2>/dev/null
rm /tmp/lastthresh.out   2>/dev/null
rm /tmp/lastthresh.err   2>/dev/null

#Use this in the query of instances connected to T/EC to filter out
#T/EC's own heartbeat.
source="'Tivoli;TME 10 Enterprise Console;3.1'"
sub_source="'Tivoli;Tivoli/Enterprise Console;3.1'"
hostname="'`hostname`'";

#get the current timestamp from my 'timesec' routine
#and subtract 3600 seconds or 1 hour from it.
now=`$BINDIR/TME/TEC/interapp/timesec`
now=`expr $now - 3600`

#now get all the instances from our table that are 60 minutes
#or less
echo "connect tec"                                                 > $DATFILE
echo "."                                                          >> $DATFILE
echo "buffer 5000"                                                >> $DATFILE
echo "."                                                          >> $DATFILE
echo "SELECT source, sub_source, hostname, origin, sub_origin, date_reception"    >> $DATFILE
echo "FROM tec_t_gem_threshold"                                   >> $DATFILE
echo "WHERE (date_reception > `echo $now`)"                       >> $DATFILE
echo "  AND (origin IS NOT NULL OR hostname IS NOT NULL)"         >> $DATFILE
echo "  AND (source <> $source OR"                                >> $DATFILE
echo "       sub_source <> $sub_source OR"                        >> $DATFILE
echo "       hostname <> $hostname)"                              >> $DATFILE

echo "ORDER BY 1, 2, 3, 4, 5"                                     >> $DATFILE
echo "."                                                          >> $DATFILE
echo "quit"                                                       >> $DATFILE
echo "."                                                          >> $DATFILE

# this gets the list of connections from the SQL database
# in sorted order.  The output may contain duplicate records
# because RIM does not support the 'Select distinct...' call
#
# if /tmp/lastthresh.err exists and is not empty, assume the WRIMSQL call
# failed.

wrimsql -e < /tmp/lastthresh.in 1>/tmp/lastthresh.out 2>/tmp/lastthresh.err

if [ -s /tmp/lastthresh.err ]

 then
  echo WRIMSQL call failed.
  rm /tmp/lastthresh.in
  rm /tmp/lastthresh.out
  rm /tmp/lastthresh.err
  exit 1
fi

#/tmp/lastthresh.out contains a record of each instance in sorted order.
#tecthreshold.awk will count the number of identical rows
#in /tmp/lastthresh.out and output a record with a count for each distinct row

if [ $UNAME = "SunOS" ]
   then /usr/xpg4/bin/awk -f $BINDIR/TME/TEC/interapp/tecthreshold.awk < /tmp/lastthresh.out > /tmp/lastthresh.in
   else awk -f $BINDIR/TME/TEC/interapp/tecthreshold.awk < /tmp/lastthresh.out > /tmp/lastthresh.in
fi

#awk it once again to put the prefix (1=, 2=, etc) in front of the
#origin, sub_origin fields

if [ $UNAME = "SunOS" ]
   then /usr/xpg4/bin/awk -f $BINDIR/TME/TEC/interapp/tt_convert.awk < /tmp/lastthresh.in > /tmp/lastthresh.out
   else awk -f $BINDIR/TME/TEC/interapp/tt_convert.awk < /tmp/lastthresh.in > /tmp/lastthresh.out
fi

#go through each record in /tmp/lastthresh.in.  For each record,
#post an APM_THRESHHOLD event
DATFILE=/tmp/lastthresh.in
hostname=`hostname`

{
while read row;
   do
   read apm_monitor
   read apm_count
   read apm_source
   read apm_sub_source
   read apm_hostname
   read apm_origin
   read apm_sub_origin
   apm_count=`echo $apm_count | cut -d':' -f2`
   apm_source=`echo $apm_source | cut -d':' -f2`
   apm_sub_source=`echo $apm_sub_source | cut -d':' -f2`
   apm_hostname=`echo $apm_hostname | cut -d':' -f2`
   apm_origin=`echo $apm_origin | cut -d':' -f2`
   apm_sub_origin=`echo $apm_sub_origin | cut -d':' -f2`
   echo '"APM_THRESHOLD;'                                            > $DATFILE
   echo "source='Tivoli;TME 10 Enterprise Console;3.1';"            >> $DATFILE
   echo "sub_source='Tivoli;Tivoli/Enterprise Console;3.1';"        >> $DATFILE
   if [ -n "$windir" ]
     then echo "origin='2=`echo $THISHOSTNAME`;1=`ipconfig | awk /"IP Address"/'{print $12}'`';" >> $DATFILE
     else echo "origin='2=`echo $THISHOSTNAME`;1=`nslookup $THISHOSTNAME | awk /Address:/'{last=$2} END {print last}'`';" >> $DATFILE
   fi
   echo "sub_origin='0=TECID=0;0=TECID=0';"                         >> $DATFILE
   echo "hostname=`echo $THISHOSTNAME`;"                            >> $DATFILE
   if [ -n "$windir" ]
      then THRESHSTRING=`perl $BINDIR/TME/TEC/interapp/tecthreshold.pl $apm_count $BINDIR/TME/TEC/interapp/thresh.rate`
      else THRESHSTRING=`/etc/Tivoli/bin/perl $BINDIR/TME/TEC/interapp/tecthreshold.pl $apm_count $BINDIR/TME/TEC/interapp/thresh.rate`
   fi
   if [ -n "$THRESHSTRING" ] ; then
      echo "severity=$THRESHSTRING;"                                   >> $DATFILE
      echo "msg='Requested Last Threshold';"                           >> $DATFILE
      echo "value=`echo $apm_count`;"                                  >> $DATFILE
      echo "monitor='Events Received Rate';"                           >> $DATFILE
      echo "apm_relationship_class='TEC Event';"                       >> $DATFILE
      echo "apm_relationship_dir=2;"                                   >> $DATFILE
      echo "apm_source='`echo $apm_source`';"                          >> $DATFILE
      echo "apm_sub_source='`echo $apm_sub_source`';"                  >> $DATFILE
      echo "apm_origin='`echo $apm_origin`';"                          >> $DATFILE
      echo "apm_sub_origin='`echo $apm_sub_origin`';"                  >> $DATFILE
      echo "apm_hostname='`echo $apm_hostname`';"                      >> $DATFILE
      if [ -n "$WINOS" ] || [ $UNAME = "SunOS" ]; then
         echo "END"                                                    >> $DATFILE
         echo '"'                                                      >> $DATFILE
      else
         echo 'END\n\001"'                                             >> $DATFILE
      fi

      echo
      cat $DATFILE
      cat $DATFILE | idlcall -v $EVENTSERVEROID send_event
   fi
   done
} < /tmp/lastthresh.out

rm /tmp/lastthresh.in
rm /tmp/lastthresh.out
rm /tmp/lastthresh.err

echo
echo done
exit 0


