#!/etc/Tivoli/bin/perl
# *******************************************************************
#   +-------------------------------------------------------------------+
#   | Licensed Materials - Property of IBM                              |
#   | 5697-B83                                                          |
#   | (C) Copyright Tivoli Systems, an IBM Company 1982, 1997           |
#   | All rights reserved.                                              |
#   | (C) Copyright IBM Corp. 1982, 1997.  All rights reserved.         |
#   |                                                                   |
#   | US Government Users Restricted Rights - Use, duplication or       |
#   | disclosure restricted by GSA ADP Schedule Contract with IBM Corp. |
#   +-------------------------------------------------------------------+
# Name:     getLastThreshold
#
# Function: This subroutine gets the last value for the SentryMonitor requested for
#           a ManagedNode passed as a parameter.
#
# Parameters: hostname, SentryMonitor
#
# Returns:    To STDOUT:
#             TEC_severity, last_monitor_value, monitor_name
#
#
# **********************************************

 $hostname=$ARGV[0];
 $monitorname= $ARGV[1];


# Strip spaces, parentheses and underscores from monitor name input variable
 $_ = $monitorname;
 s/[ ,_,\(,\)]//g;
 $monitorname = $_;

 if ($monitorname eq "") {
    print "Usage:  getLastThreshold.pl <hostname> <monitorname>\n";
    exit 1;
 }

 local($monitor) = 0;                                       # flag for monitor data
 local($response) = 0;                                      # flag for response data
 reset 'Q';                                                 # clean associative array Q_data
 open(MONITORS, "wlseng -l '*' '$monitorname' '*' $hostname |");      # pipe the monitors from wlseng

 Monitors:
  while (<MONITORS>) {

    if (/^\n/) {}                                           # skip any blank lines

    elsif (/^Monitoring probes:/) {                         # look for start of Monitor data
      $monitor = 1;                                         # signal we are in monitor section
    }

    elsif (/^Responses:/) {
      $monitor = 0;                                         # look for start of Response data
      $response = 1;                                        # signal we are in response section
    }

    elsif ($monitor) {                                      # handle monitor data
      if (/(<<.*>>)\s+\(.*\)(\S+) (.*);/) {                 # first line of monitor data
        $monitor_spec = $1;                                 # long, unique name for monitor
        $monitor_name = $2;                                 # short monitor name
        @triggerValues = split(/, /,$3);                    # trigger values
        $monitor_name =~ s/"//g;                            # remove quotes from monitor name
        $Q_data{$monitor_spec} = $monitor_name;             # save monitor name
      }
      elsif (/Last value: (.*)/) {                          # second line of monitor data
        $last_trigger_value = $1;                           # get last monitor value
        $Q_data{$monitor_spec} .= ",".$last_trigger_value;
        if ($last_trigger_value eq "<none>") {              # if trigger never fired ...
          $Q_data{$monitor_spec} .= ",UNKNOWN";             # ... use unknown status
        }
        else {                                              # trigger has fired
          $trig_val = "";
          for ($i = 0; $i < $#triggerValues && $trig_val eq ""; $i++) {
            ($comp_val,$sentry_severity) = split(/:/,$triggerValues[$i],2);
            ($comp_op, $comp_val) = split(/ /,$comp_val,2);
            $comp_val =~ s/[ "]//g;                         # remove spaces and quotes
            $sentry_severity =~ s/[ "]//g;                  # remove spaces and quotes

            if ($comp_val =~ /^\D/) {                       # non-numeric test
              if    ($comp_op eq "==") {$comp_op = "eq";}   # if not a number, ...
              elsif ($comp_op eq "->") {$comp_op = "eq";}   # each numeric operator ...
              elsif ($comp_op eq "!=") {$comp_op = "ne";}   # must be converted ...
              elsif ($comp_op eq ">")  {$comp_op = "gt";}   # to its related ...
              elsif ($comp_op eq ">=") {$comp_op = "ge";}   # string operator ...
              elsif ($comp_op eq "<")  {$comp_op = "lt";}   # for Perl to evaluate ...
              elsif ($comp_op eq "<=") {$comp_op = "le";}   # it correctly.
              else  {print "Conversion error with $comp_op operator!\n";}
            }

            if (eval($last_trigger_value." ".$comp_op." ".$comp_val)) {
              $trig_val = $sentry_severity;
            }
          }
          if ($trig_val eq "") {                             # if all tests fail, use default value
            ($trig_val = $triggerValues[$i]) =~ s/[ :"]//g;  # remove unneeded chars
          }
          $Q_data{$monitor_spec} .= ",".$trig_val;           # save sentry severity of last trigger
        }
        $Q_data{$monitor_spec} .= ",UNKNOWN"                 # T/EC severity not known until later
      }
    }                                                        # end if ($monitor)

    elsif ($response) {                                      # handle response data
      if (/(<<.*>>)\s+<<.*>> (\S+)/) {                       # first line of response data
        $monitor_spec = $1;
        $sentry_response = $2;
        ($monitor_name, $sentry_severity, $tec_severity) = split(/,/,$Q_data{$monitor_spec});
        if ($sentry_response ne $sentry_severity || $tec_severity ne "UNKNOWN") {
          $sentry_response = "IGNORE";
        }
      }
      elsif (/tec\(.*","(\S+)","/) {                         # second line of response data
        $tec_response = $1;                                  # get associated T/EC severity
        if ($sentry_response ne "IGNORE") {                  # if previous response not used, save it
          $Q_data{$monitor_spec} = $monitor_name.",".$sentry_response.",".$tec_response;
        }
      }
      else {}
    }

    else {}                                                  # ignore all other lines
  }                                                          # end while MONITORS

  @monitorValueArray = values %Q_data;                       # assign assoc array to normal array
  for $i (0 .. $#monitorValueArray) {                        # remove unwanted data ...
    $monitorValueArray[$i] =~ s/(.*),(.*),(.*),(.*)/$3 $2 $1/;       # ... which is sentry severity
    print $monitorValueArray[$i]."\n";
  }
  close MONITORS;                                            # done with wlseng data
