#!/bin/sh
##############################################################################
#
#   +-------------------------------------------------------------------+
#   | Licensed Materials - Property of IBM                              |
#   | 5697-B83                                                          |
#   | (C) Copyright Tivoli Systems, an IBM Company 1982, 1997           |
#   | All rights reserved.                                              |
#   | (C) Copyright IBM Corp. 1982, 1997.  All rights reserved.         |
#   |                                                                   |
#   | US Government Users Restricted Rights - Use, duplication or       |
#   | disclosure restricted by GSA ADP Schedule Contract with IBM Corp. |
#   +-------------------------------------------------------------------+
#
# Program:      getLastThreshold
#
# Description:  Returns the last threshold value for a TEC monitor
#
# Author:       Randy Rendahl  4/25/97
#
# Parameters:   1. The suborigin of the component instance monitored
#               2. The Name of the monitor as defined in CDF
#
# Invocation:   Invoked from the GUI
#
# Changes:      9/29/97 Defect 36110 - doesn't handle invalid monitor names
#                       changed "echo "monitor=`echo $monitorcodename`;"  to
#                               "echo "monitor=`echo $monitorname`;"
#
#
#
##############################################################################
profilename="Tivoli;Tivoli/Enterprise Console;3.1"
suborigin=$1
monitorname=$2

if [ -z "$monitorname" ];
then
   echo "Usage: getLastThreshold.sh <suborigin> <monitorname>"
   exit 1
fi

HOSTNAME=`hostname`
DATFILE=/tmp/threshold.in
TNR=`wlookup NameRegistry`
ES=`idlcall $TNR local_lookup '"EventServer" "EventServer"'`
EVENTSERVEROID=`idlarg 1 $ES`

#Create Operating System Flag
if [ -n "$windir" ] ; then
   WINOS=`echo $windir | awk /:/'{ print substr($1,4) }'`
   WINDRIVE=`echo $windir | awk /:/'{ print substr($1,1,2) }'`
fi

if [ -n "$WINOS" ]
  then source $WINDRIVE/$WINOS/system32/drivers/etc/Tivoli/setup_env.sh
  else . /etc/Tivoli/setup_env.sh
fi

if [ ! -d /tmp ]
   then mkdir /tmp
fi

#kludge to support Solaris, nslookup is in one of these paths
PATH=$PATH:/usr/sbin:/usr/etc
export PATH
UNAME=`uname`

echo Getting last threshold information...

#change blanks to underscores to create a monitor filename
monitorcodename=`echo "$monitorname" | sed s/" "/""/g`
monitorcodename=`echo "$monitorcodename" | sed s/"("/""/g`
monitorcodename=`echo "$monitorcodename" | sed s/")"/""/g`

$BINDIR/TME/TEC/interapp/getLastThreshold.pl $HOSTNAME "$monitorcodename" > $BINDIR/TME/TEC/interapp/tvalues.dat

# defect 36110
if [ ! -s $BINDIR/TME/TEC/interapp/tvalues.dat ]; then
   echo "Error: Invalid monitor name."
   echo "Abnormal termination"
   exit 1
fi

if [ "*" != "$monitorname" ]; then
 echo "$monitorname" > $BINDIR/TME/TEC/interapp/monitors.dat
else
 wlsmon "$profilename" | grep -i "Monitor:" | cut -d" " -f4- | tr -d '\015' > $BINDIR/TME/TEC/interapp/monitors.dat
fi

   {
   while read monitorentry;
      do
      monitorentry=`echo "$monitorentry" | sed s/"()"/""/g`

      #change blanks to underscores to create a monitor filename
      monitorcodename=`echo "$monitorentry" | sed s/" "/""/g`
      monitorcodename=`echo "$monitorcodename" | sed s/"("/""/g`
      monitorcodename=`echo "$monitorcodename" | sed s/")"/""/g`
      threshold=`grep "$monitorcodename" $BINDIR/TME/TEC/interapp/tvalues.dat`
      severity=`echo $threshold | cut -d" " -f1 | tr '[a-z]' '[A-Z]'`

      if [ $UNAME = "SunOS" ]
         then severity=`echo $severity | /usr/xpg4/bin/awk -f $BINDIR/TME/TEC/interapp/glt_convert.awk`
         else severity=`echo $severity | awk -f $BINDIR/TME/TEC/interapp/glt_convert.awk`
      fi

      value=`echo $threshold | cut -d" " -f2`

      if [ "UNKNOWN" != "$severity" ]; then

        echo '"APM_THRESHOLD;'                                            > $DATFILE
        echo "source='Tivoli;TME 10 Enterprise Console;3.1';"            >> $DATFILE
        echo "sub_source='Tivoli;Tivoli/Enterprise Console;3.1';"        >> $DATFILE
        if [ -n "$windir" ]
          then echo "origin='2=`echo $HOSTNAME`;1=`ipconfig | awk /"IP Address"/'{print $12}'`';" >> $DATFILE
          else echo "origin='2=`echo $HOSTNAME`;1=`nslookup $HOSTNAME | awk /Address:/'{last=$2} END {print last}'`';" >> $DATFILE
        fi
        echo "sub_origin='0=TECID=0;0=TECID=0';"                         >> $DATFILE
        echo "hostname=`echo $HOSTNAME`;"                                >> $DATFILE
        echo "severity=`echo $severity`;"                                >> $DATFILE
        echo "msg='Requested Last Threshold';"                           >> $DATFILE
        echo "value=`echo $value`;"                                      >> $DATFILE
#       echo "monitor=`echo $monitorcodename`;"                          >> $DATFILE
        echo "monitor='`echo $monitorname`';"                            >> $DATFILE
        if [ -n "$WINOS" ] || [ $UNAME = "SunOS" ];
          then echo "END"                                                >> $DATFILE
               echo '"'                                                  >> $DATFILE
        else
          echo 'END\n\001"'                                              >> $DATFILE
        fi
        echo
        cat $DATFILE
        cat $DATFILE | idlcall -v $EVENTSERVEROID send_event

      fi
      done
   } < $BINDIR/TME/TEC/interapp/monitors.dat

echo
rm $DATFILE
echo done
exit 0

