#!/etc/Tivoli/bin/perl
# *******************************************************************
#   +-------------------------------------------------------------------+
#   | Licensed Materials - Property of IBM                              |
#   | 5697-B83                                                          |
#   | (C) Copyright Tivoli Systems, an IBM Company 1982, 1997           |
#   | All rights reserved.                                              |
#   | (C) Copyright IBM Corp. 1982, 1997.  All rights reserved.         |
#   |                                                                   |
#   | US Government Users Restricted Rights - Use, duplication or       |
#   | disclosure restricted by GSA ADP Schedule Contract with IBM Corp. |
#   +-------------------------------------------------------------------+
# Name:     getMonitorPulse
#
# Author:   Kevin Norsworthy            Tivoli Systems 4/23/97
#
# Function: This subroutine gets the Sentry Monitor pulse value in use
#
# Parameters: hostname, monitorname
#
# Returns:    A record of the following format
#
#             monitor_name pulse_interval, pulse_period
#
#             For example:
#
#                Heartbeat 10 minutes
#
# **********************************************
 $hostname=$ARGV[0];
 $monitorname= $ARGV[1];

# Strip spaces, parentheses, and underscores from monitorname input variable

 $_ = $monitorname;
 s/[ ,_,\(,\)]//g;
 $monitorname = $_;

 local($timer) = 0;                                         # flag for timer data
 local($monitor) = 0;                                       # flag for monitor data
 local($responses) = 0;                                     # flag for responses data

 if ($monitorname eq "") {
    print "Usage:  getMonitorPulse.pl <hostname> <monitorname>\n";
    exit 1;
 }


# print STDERR "executing cmd: wlseng -l $hostname $monitorname\n";       # log command name in case errs get logged
 open(MONITORS, "wlseng -l '*' $monitorname '*' $hostname |");      # pipe the monitors from wlseng


 Monitors:
  while (<MONITORS>) {

    if (/^\n/) {}                                           # skip any blank lines

    elsif (/^Monitoring probes:/) {                         # look for start of Monitor data
      $monitor = 1;
      $timer = 0;                                           # signal we are in monitor section
    }

    elsif (/^Timer:/) {                                     # look for start of Timer data
      $timer = 1;                                           # signal we are in timer section
    }

    elsif (/^Responses:/) {
      $monitor = 0;                                         # look for start of Response data
      $response = 1;
      $timer =0;                                            # signal we are in response section
    }

    if ($timer) {                                           # Process Timer section of WLSENG
      if (/(<<.*>)<(.*)>(<.*>>)\s+(.+):(.):(.*)/) {         # Break the line up into significant chunks
        $monitor_name = $2;                                 # Assign sections to variables
        $interval =$4;
        $period =$5;
        if (($period eq 'w') || ($period eq 'W')) {
            $period =~ s/w/m/i;
            $interval =(10080*int($interval));
            }
        if (($period eq 'd') || ($period eq 'D')) {
            $period =~ s/d/m/i;
            $interval =(1440*int($interval));
            }
        if (($period eq 'h') || ($period eq 'H')) {
            $period =~ s/h/m/i;
            $interval =(60*int($interval));
            }
        $period =~ s/m/minutes/i;

#        print "______________________\n";
        $record = "$interval $period ";        # create an interval record for each monitor
        print "$record\n";
        }
        }

 }                                                          # end while MONITORS

  close MONITORS;                                            # done with wlseng data
