#!/etc/Tivoli/bin/perl
# *******************************************************************
#   +-------------------------------------------------------------------+
#   | Licensed Materials - Property of IBM                              |
#   | 5697-B83                                                          |
#   | (C) Copyright Tivoli Systems, an IBM Company 1982, 1997           |
#   | All rights reserved.                                              |
#   | (C) Copyright IBM Corp. 1982, 1997.  All rights reserved.         |
#   |                                                                   |
#   | US Government Users Restricted Rights - Use, duplication or       |
#   | disclosure restricted by GSA ADP Schedule Contract with IBM Corp. |
#   +-------------------------------------------------------------------+
# Name:       getMonitorThresholds
#
# Author:     Kevin Norsworthy            Tivoli Systems 4/25/97
#
# Function:   This subroutine gets the Sentry Monitor thresholds values in use
#
# Parameters: hostname, monitorname
#
# Returns:    A record of the following format
#
#             severity_level operator value ...
#
#             For example:
#
#              severe > 10 CRITICAL warning > 5 WARNING
#
# **********************************************
 $hostname=$ARGV[0];
 $monitorname= $ARGV[1];

# Strip spaces, parenthese, and underscores from monitorname input variable
 $_ = $monitorname;
 s/[ ,_,\(,\)]//g;
 $monitorname = $_;

 if ($monitorname eq "") {
    print "Usage:  getMonitorThresholds.pl <hostname> <monitorname>\n";
    exit 1;
 }

 local($timer) = 0;                                         # flag for timer data
 local($monitor) = 0;                                       # flag for monitor data
 local($responses) = 0;                                     # flag for responses data
 open(MONITORS, "wlseng -l '*' $monitorname '*' $hostname |");      # pipe the monitors from wlseng

 Monitors:
  while (<MONITORS>) {

    if (/^\n/) {}                                           # skip any blank lines

    elsif (/^Monitoring probes:/) {                         # look for start of Monitor data
      $monitor = 1;
      $timer = 0;                                           # signal we are in monitor section
      $response = 0;
    }

    elsif (/^Timer:/) {                                     # look for start of Timer data
      $timer = 1;                                           # signal we are in timer section
      $monitor = 0;                                         # look for start of Response data
      $response = 0;
    }

    elsif (/^Responses:/) {
      $response = 1;
      $monitor = 0;                                         # look for start of Response data
      $timer =0;                                            # signal we are in response section
    }

    if ($monitor) {                                         # Process Response section of WLSENG
     if (/(<<.*>)<(.*)>(<.*>>)\s+\((.*)\)\s+(.*)\s+(.*);/) {    # Break the line up into significant chunks
        $monitor_name = $2;                                 # Assign sections to variables
        $thresholds = $5;                                   # Assign sections to variables
        @triggerValues = split(/, /,$thresholds);
        for ($i=0; $i < $#triggerValues; $i++) {
#          print "triggerValues[i]= $triggerValues[$i]\n";
          ($oper, $valu, $colon, $severity) = split(/ /, $triggerValues[$i]);
          $severity =~ s/"//g;
          $level = $severity;

          print "$severity $oper $valu $level ";           # return the thresholds
          }
      }
     }

 }                                                          # end while MONITORS

  print "\n";                                               # close the record
  close MONITORS;                                           # done with wlseng data

