#!/bin/sh
#   +-------------------------------------------------------------------+
#   | Licensed Materials - Property of IBM                              |
#   | 5697-B83                                                          |
#   | (C) Copyright Tivoli Systems, an IBM Company 1982, 1997           |
#   | All rights reserved.                                              |
#   | (C) Copyright IBM Corp. 1982, 1997.  All rights reserved.         |
#   |                                                                   |
#   | US Government Users Restricted Rights - Use, duplication or       |
#   | disclosure restricted by GSA ADP Schedule Contract with IBM Corp. |
#   +-------------------------------------------------------------------+
#-------------------------------------------------------------------------------
#
# Program:      installTECMons.sh
#
# Description:  Creates a Policy Region named "TEC Collection".
#               Creates a Profile Manager named "Tivoli;Tivoli/Enterprise Console;3.1
#               Installs the TEC.col monitor collection on current machine
#               Installs the monitors into the "Tivoli;Tivoli/Enterprise Console;3.1"
#                  Profile Manager
#
# Author:       Paul J. Liskay 02/12/97
#
# Parameters:   None
#
# Returns:      0 - normal completion
#               1 - abnormal termination
#
# Assumptions:
#
# Limitations:
#
#
# Changes:      10/27/97 D 37117 Check to see if Profile already exists, if it does, then
#                        don't do the WADDMON's at the bottom of the script
# 
#-------------------------------------------------------------------------------

###### Find the InterRegion, Policy Region, Adminstrator

IRO=`wlookup InterRegion`
IROname=`idlattr -t -g $IRO name string`
IROname=`eval echo $IROname`
admin=`wlookup -r Administrator -a | awk '/Root/ \
{print $1}'`
if [ "X$admin" = "X" ]; then
   admin=Bogus
fi

echo
echo "InterRegion:  " $IRO
echo "Policy Region:" $IROname
echo "Administrator:" $admin

###### See if the Profile already exists, if so, then down the road don't reinstall Monitors
PROFILE=`wlookup -r SentryProfile "Tivoli;Tivoli/Enterprise Console;3.1"`

###### Create the Profile Manager
echo
echo "Creating Profile Manager 'TEC Collection'..."
wcrtprfmgr @PolicyRegion:$IROname "TEC Collection"

###### Create the Profile
echo
echo "Creating Profile 'Tivoli;Tivoli/Enterprise Console;3.1'..."
wcrtprf @ProfileManager:"TEC Collection#$IROname" SentryProfile "Tivoli;Tivoli/Enterprise Console;3.1"

###### Install the "APM_TEC_Monitors" Monitor Collection
echo
echo "Installing the 'APM_TEC_Monitors' Monitor Collection"
mcsl -R -i TEC.col

###### Install the Monitors to Profile
echo
echo "Installing the monitors from the 'APM_TEC_Monitors' collection..."

profilename="Tivoli;Tivoli/Enterprise Console;3.1"
SP="$profilename#$IROname"

#exit now if Profile "Tivoli;Tivoli/Enterprise Console;3.1" already exists...
if [ -n "$PROFILE" ]; then 
   echo "FINISHED"
   exit 0
fi 

# Add the new Sentry severity levels
waddlevel fatal 1500 "$profilename#$IROname"
waddlevel harmless 50 "$profilename#$IROname"

waddmon "APM_TEC_Monitors" "TECDataBaseStatus" -t "1 hours" -d \
  -c warning -R "==" "down" -T WARNING EventServer \
"$SP"
echo "Added TEC DataBase Status Monitor"

waddmon "APM_TEC_Monitors" "TECServerStatus" -t "1 hours" -d \
  -c warning -R "==" "down" -T WARNING EventServer \
"$SP"
echo "Added TEC Server Status Monitor"

waddmon "APM_TEC_Monitors" "Heartbeat" -t "1 hours" -d \
"$SP"
echo "Added TEC Heartbeat Monitor"

waddmon "APM_TEC_Monitors" "EventsReceivedRate" -t "1 hours" -d \
"$SP"
echo "Added TEC Events Received Hour Monitor"

waddmon "APM_TEC_Monitors" "EventsSentRate" -t "1 hours" -d \
"$SP"
echo "Added TEC Events Sent Hour Monitor"

waddmon "APM_TEC_Monitors" "TECConnectionChange" -t "1 hours" -d \
"$SP"
echo "Added TEC Connection Change Monitor"

waddmon "APM_TEC_Monitors" "TECDeviceSpaceUsedMB" -t "1 hours" -d \
  -c warning -R ">" 10.0 -T WARNING EventServer \
"$SP"
echo "Added TEC Device Space Used Monitor"

waddmon "APM_TEC_Monitors" "TECDeviceSpaceUsedpct" -t "1 hours" -d \
  -c critical -R ">" 90.0 -T CRITICAL EventServer \
  -c warning -R ">" 70.0 -T WARNING EventServer \
"$SP"
echo "Added TEC Device Space Usedpct Monitor"

waddmon "APM_TEC_Monitors" "TECDeviceSpaceFreeMB" -t "1 hours" -d \
  -c critical -R "<" 1.0 -T CRITICAL EventServer \
  -c warning -R "<" 5.0 -T WARNING EventServer \
"$SP"
echo "Added TEC Device Space Free Monitor"

waddmon "APM_TEC_Monitors" "TECDeviceSpaceFreepct" -t "1 hours" -d \
  -c critical -R "<" 10.0 -T CRITICAL EventServer \
  -c warning -R "<" 30.0 -T WARNING EventServer \
"$SP"
echo "Added TEC Device Space Freepct Monitor"

echo "FINISHED"
