#!/etc/Tivoli/bin/perl
#-------------------------------------------------------------------------------
#   +-------------------------------------------------------------------+
#   | Licensed Materials - Property of IBM                              |
#   | 5697-B83                                                          |
#   | (C) Copyright Tivoli Systems, an IBM Company 1982, 1997           |
#   | All rights reserved.                                              |
#   | (C) Copyright IBM Corp. 1982, 1997.  All rights reserved.         |
#   |                                                                   |
#   | US Government Users Restricted Rights - Use, duplication or       |
#   | disclosure restricted by GSA ADP Schedule Contract with IBM Corp. |
#   +-------------------------------------------------------------------+
# Program:      setthreshold.pl
#
# Description:  Translates input parameters of the format
#               <threshold value>, <relative operator enum>, <severity enum>[,...
#               into the file $BINDIR/TME/TEC/interapp/thresh.rate
#
#               Since the file consists of a comment line, and 6 lines
#               of 3 fields each, we will create the file by having
#               an array for each of the three fields.  These arrays
#               are named @SEVERITY[], @RELATIVEOP[], and @THRESHOLD[].
#
# Author:       Paul Liskay   5/14/97
#               Darren Dunne  5/14/97
#
# Parameters:   "<threshold>, <relative op enum>, <severity enum>[,..."
#               e.g. setthreshold.pl "100,0,2,150,0,4,200,0,5"
#
# Returns:      0 - normal completion
#               1 - abnormal termination
#
# Assumptions:
#
# Limitations:
#
#-------------------------------------------------------------------------------

# check for $BINDIR
$BINDIR = "";
$BINDIR = $ENV{'BINDIR'};
$_ = $BINDIR;
s/\\/\//g;
$BINDIR = $_;
if ($BINDIR eq "")
   {
   die "You must set the BINDIR environment variable\nRun /etc/Tivoli/setup_env.{sh/csh}";
   }

# check for paramters
if ($ARGV[0] eq "")
  {
  die "Usage: setrelthreshold \"<threshold>,<rel. op. enum>,<sev. enum>[,...\"\n";
  }

# initialize all the values of the threshold values and relative
# operator arrays to be -1 in case the input parameters does not
# set a particular severity level.

for ($i=0; $i<=5; $i++)
  {
  @THRESHOLD[$i]= -1;
  @RELATIVEOP[$i]=  -1;
  }

# now set the values of these arrays to what is specified in the
# input parameters

@WORDS=split(/\D+/, $ARGV[0]);

for ($i=1; $i<=($#WORDS + 1)/3; $i++)
  {
  @THRESHOLD[@WORDS[3*$i]]=@WORDS[3*$i-1];
  @RELATIVEOP[@WORDS[3*$i]]=@WORDS[3*$i-2];
  }

# set the @SEVERITY array with literals

for ($i=0; $i <=5; $i++)
   {
   @SEVERITY[$i]=`echo $i | awk -f $BINDIR/TME/TEC/interapp/tv_convert.awk`;
   chop @SEVERITY[$i];
   }

# create the "$BINDIR/TME/TEC/interapp/thresh.rate" file
# by printing a comment line, followed by the same element from each
# of the three arrays.  Print from the highest to lowest severity levels

open(THRESH, ">$BINDIR/TME/TEC/interapp/thresh.rate") ||die "Could not open 'thresh.rate' for output.\n";
#print        "#format: 'severity' 'relative operator enum' 'threshold value'\n";
print THRESH "#format: 'severity' 'relative operator enum' 'threshold value'\n";
for ($i=5; $i >= 0; $i--)
  {
#  printf        "%-10s %4d %4d\n", @SEVERITY[$i], @THRESHOLD[$i], $RELATIVEOP[$i];
  printf THRESH "%-10s %4d %4d\n", @SEVERITY[$i], @THRESHOLD[$i], $RELATIVEOP[$i];
  }

close THRESH;
exit 0

